#include <owl\applicat.h>
#include <owl\framewin.h>
#include <owl\checkbox.h>
#include <owl\edit.h>
#include <owl\groupbox.h>
#include <string.h>
#include <cstring.h>
#include "colctlfr.rh"


class TWndw : public TFrameWindow {
public:
	TWndw(TWindow *parent, const char far *title);
	~TWndw();
protected:
	void SetupWindow();
	HBRUSH EvCtlColor(HDC, HWND hWndChild, UINT ctlType);
	BOOL EvEraseBkgnd(HDC);
	void EvSysColorChange();
	void EvSize(UINT sizeType, TSize& size);
	void CmGetData();
private:
	TEdit *edit;
	TCheckBox *check1, *check2, *check3;
	TBrush *bkgndBrush;
DECLARE_RESPONSE_TABLE(TWndw);
};

DEFINE_RESPONSE_TABLE1(TWndw, TFrameWindow)
	EV_WM_CTLCOLOR,
	EV_WM_ERASEBKGND,
	EV_WM_SYSCOLORCHANGE,
	EV_WM_SIZE,
	EV_COMMAND(CM_GETDATA, CmGetData),
END_RESPONSE_TABLE;


TWndw::TWndw(TWindow *parent, const char far *title)
	: TFrameWindow(parent, title)
{
	AssignMenu(MENU_1);
//	Attr.Style &= ~(WS_MAXIMIZEBOX | WS_THICKFRAME);
	Attr.X = 20;
	Attr.Y = 20;
	Attr.W = 200;
	Attr.H = 350;

	EnableKBHandler();
	edit = new TEdit(this, ID_EDIT, "Default",
		40, 40, 100, 24, 15);
	TGroupBox *groupBox1 = new TGroupBox(this, -1,
		"Check Boxes", 40, 75, 110, 125);
	check1 = new TCheckBox(this, ID_CHECK1, "Check1",
		52, 105, 68, 24, groupBox1);
	check2 = new TCheckBox(this, ID_CHECK2, "Check2",
		52, 132, 68, 24, groupBox1);
	check3 = new TCheckBox(this, ID_CHECK3, "Check3",
		52, 159, 68, 24, groupBox1);
	new TButton(this, CM_GETDATA, "Get Data",
		50, 220, 80, 50);

	bkgndBrush = new TBrush(::GetSysColor(COLOR_BTNFACE));
}


void TWndw::SetupWindow()
{
	TFrameWindow::SetupWindow();

	check1->Check();
	check2->Uncheck();
	check3->Uncheck();
}


TWndw::~TWndw()
{
	delete bkgndBrush;
}


HBRUSH TWndw::EvCtlColor(HDC hdc, HWND hWndChild, UINT ctlType)
{
/*
	//if you don't want to change individual controls, it would work too.
	//change "/*" above to "//*" and see the difference.
	::SetBkColor(hdc, ::GetSysColor(COLOR_BTNFACE));
	return *bkgndBrush;
/*///*
	TDC dc(hdc);
	switch (ctlType) {
//#define CTLCOLOR_MSGBOX         0
//#define CTLCOLOR_EDIT           1
//#define CTLCOLOR_LISTBOX        2
//#define CTLCOLOR_BTN            3
//#define CTLCOLOR_DLG            4
//#define CTLCOLOR_SCROLLBAR      5
//#define CTLCOLOR_STATIC         6
//#define CTLCOLOR_MAX            7
		case CTLCOLOR_EDIT:
			dc.SetBkColor(::GetSysColor(COLOR_BTNFACE));
			dc.SetTextColor(TColor::Black);
			return *bkgndBrush;
		case CTLCOLOR_BTN:
			dc.SetBkColor(::GetSysColor(COLOR_BTNFACE));
			dc.SetTextColor(TColor::Black);
			return *bkgndBrush;
	}

	return TFrameWindow::EvCtlColor(hdc, hWndChild, ctlType);
//*/
}


BOOL TWndw::EvEraseBkgnd(HDC hDC)
{
	TDC dc(hDC);

	// SysColors that are bkgnds for text are never dithered & can use FastRect
	TRect rect = GetClientRect();
	dc.TextRect(rect, ::GetSysColor(COLOR_BTNFACE));

	// These sysColors might be dithered. PaBlt is an easy way to paint these
	TBrush highlight(::GetSysColor(COLOR_BTNHIGHLIGHT));
	dc.SelectObject(highlight);
	dc.PatBlt(0, 0, rect.right, 2);
	dc.PatBlt(0, 2, 2, rect.bottom - 2);

	TBrush shadow(::GetSysColor(COLOR_BTNSHADOW));
	dc.SelectObject(shadow);
	dc.PatBlt(1, rect.bottom - 2, rect.right - 1, 2);
	dc.PatBlt(rect.right - 2, 1, 2, rect.bottom - 3);

	return TRUE;
}


void TWndw::EvSize(UINT sizeType, TSize& size)
{
	TFrameWindow::EvSize(sizeType, size);
	Invalidate();
}


void TWndw::EvSysColorChange()
{
	delete bkgndBrush;
	bkgndBrush = new TBrush(::GetSysColor(COLOR_BTNFACE));
}


void TWndw::CmGetData()
{
	string data;
	char s[100];

	data = "EDIT CONTROL:\t";
	edit->GetText(s, sizeof(s));
	data += s;
	data += "\r\n";
	data += "CHECK BOX 1:\t";

	if (check1->GetCheck() == BF_CHECKED)
		data += "Chosen\r\n";
	else
		data += "Not chosen\r\n";

	data += "CHECK BOX 2:\t";
	if (check2->GetCheck() == BF_CHECKED)
		data += "Chosen\r\n";
	else
		data += "Not chosen\r\n";

	data += "CHECK BOX 3:\t";
	if (check3->GetCheck() == BF_CHECKED)
		data += "Chosen\r\n";
	else
		data += "Not chosen\r\n";

	MessageBox(data.c_str(), "Get Data");
}

///////////////////////////////////////////////////////////////////////////
class TApp : public TApplication
{
public:
	TApp() : TApplication() {}
	void InitMainWindow();
};


void TApp::InitMainWindow()
{
	TFrameWindow *wndw = new TWndw(0, "Color Controls");
	SetMainWindow(wndw);
}


int OwlMain(int, char*[])
{
  return TApp().Run();
}

